@@ -368,7 +368,7 @@ def pytest_addoption(parser):
         parser.addoption("--non_breakable",
                          dest="non_breakable",
                          default='N',
-                         help="Determine when failure happen, the flow will break or not")
+                         help="Determine when failure happen, the flow will break or not: Y or N")
     except Exception as e:
         print("Exception when trying to run test: %s" % __file__)
         print("Python says:%s" % str(e))
